"""
        MediaHandler package:  Geotag Aeroview Ltd - 2014

        Usage:
            ...
            >> from GeoAgents import ImageProcessor
            ...
            >> ImageProcessor(<path/to/dir/of/photos/subdirs>)


"""
__author__ = 'pav'
from mediahandler.adapters.generic import ImageWrapper
from mediahandler.core.file.utils import Cleaner, getData, os, FileSystem, BadImageSwap, MultiThread
from multiprocessing import Process, Lock



THUMB_SIZES = {
    "DL": 100,
    "DM": 90,
    "DS": 80,
    "TL": 70
}

def _resizer(folder):
    init = getData(folder)
    img_list = [ImageWrapper(i) for i in init]

    for k in THUMB_SIZES:
        tmp = os.path.join(folder,k)
        if not os.path.exists(tmp):
            os.mkdir(tmp)
        for img in img_list:
            img.setStep(THUMB_SIZES[k])
            img.Thumbnail(os.path.join(tmp, img.GetFilePath().split("\\")[-1]))
    print "Finished Processing %s directory" % folder


def _reducer(folder, outdir):
    init = getData(folder)
    trash = []
    lock = Lock()

    for img in init:
        try:
            img = ImageWrapper(img)
            Process(target=MultiThread, args=(lock,img.LowQuality(os.path.join(outdir,img.GetFilePath().split("\\")[-1])))).start()
            del img
            #img.LowQuality(os.path.join(outdir,img.GetFilePath().split("\\")[-1]))
        except IOError:
            trash.append(img.GetFilePath())
            print "Bad Image"
            del img
    print "Finished Quality Reduce in %s directory" % folder
    print len(init)
    return trash

def QualityDrop(fs, out):
    dir_list = FileSystem(dir=fs).SubDirs()
    tmp = out
    #tmp = os.path.join(
    #    os.path.expanduser("~\\Desktop"),
    #    out
    #)
    if not os.path.exists(tmp):
        os.mkdir(tmp)

    for dir in dir_list:
        BadImageSwap(_reducer(dir, tmp))


def ImageProcessor(fs):
    dir_list = FileSystem(dir=fs).SubDirs()

    for dir in dir_list:
        _resizer(dir)
        Cleaner(dir)

if  __name__ == "__main__":
    QualityDrop("C:\Users\pav\Desktop\Saronikos_15_Spetsopoula" ,"C:\Users\pav\Desktop\Saronikos_15_Spetsopoula" )